.. -*- mode: rst ; ispell-local-dictionary: "american" -*-


git flow |BRANCH| pull - Pull a |BRANCH| branch from a remote peer
=======================================================================


Synopsis
-----------

.. parsed-literal::

  `git flow` |`BRANCH`| `pull` remote [name]


Description
-----------

Pull a |BRANCH| branch from a remote peer.


Positional arguments
-----------------------

  :remote:    Remote repository to pull from.
  :name:      Name of the |BRANCH| branch to pull. Defaults to the current
              branch, if it is a |BRANCH| branch.


Options
-----------

  -h, --help          Show help message and exit.
